@@ -7,7 +7,7 @@ import time
 import urllib
 
 import async_timeout
-import bleak
+
 
 ADAX_DEVICE_TYPE_HEATER_BLE = 5
 BLE_COMMAND_STATUS_OK = 0
@@ -18,6 +18,12 @@ UUID_ADAX_BLE_SERVICE_CHARACTERISTIC_COMMAND = "0000cc11-0000-1000-8000-00805f9b
 
 _LOGGER = logging.getLogger(__name__)
 
+try:
+    import bleak
+except FileNotFoundError:
+    _LOGGER.error("Import bleak failed", exc_info=True)
+    bleak = None
+
 
 class Adax:
     """Adax data handler."""
@@ -125,6 +131,10 @@ class AdaxConfig:
         _LOGGER.debug("Status %s", byte_list)
 
     async def configure_device(self):
+        if bleak is None:
+            _LOGGER.error("Bleak library not loaded")
+            return
+
         _LOGGER.debug(
             "Press and hold OK button on the heater until the blue led starts blinking"
         )
@@ -170,6 +180,9 @@ class AdaxConfig:
 
 
 async def scan_for_available_ble_device(retry=1):
+    if bleak is None:
+        _LOGGER.error("Bleak library not loaded")
+        return
     discovered = await bleak.discover(timeout=60)
     _LOGGER.debug(discovered)
     if not discovered:
